@@ -14,8 +14,8 @@ use kube::config::{Config, KubeConfigOptions, Kubeconfig};
 use kube::{Client, Resource, ResourceExt};
 use serde_json as json;
 
+use crate::location::Location;
 use crate::v0;
-use crate::Location;
 
 pub(crate) use self::helm::Helm;
 
