@@ -58,8 +58,7 @@ pub(super) fn group_nodes_by_zone(
 pub(super) fn is_aks(nodes: impl IntoIterator<Item = Node>) -> bool {
     nodes
         .into_iter()
-        .filter_map(|node| node.label(AKS_CLUSTER).map(String::from))
-        .any(|label| label.starts_with("MC_"))
+        .any(|node| node.label(AKS_CLUSTER).is_some())
 }
 
 pub(super) fn is_eks() -> bool {
