@@ -45,24 +45,30 @@ pub(crate) struct Cli {
     #[structopt(
         help = "Management server URL or address",
         // default_value = "https://api.statehub.io",
-        short,
         long,
+        short,
+        global = true,
         env = "SHAPI"
     )]
     management: Option<String>,
     #[structopt(
         help = "Console server URL or address",
         // default_value = "https://console.statehub.io",
-        short,
         long,
+        global = true,
         env = "SHCONSOLE"
     )]
     console: Option<String>,
-    #[structopt(help = "Authentication token", short, long, env = "SHTOKEN")]
+    #[structopt(help = "Authentication token", long, global = true, env = "SHTOKEN")]
     token: Option<String>,
     #[structopt(long, global = true, help = "Show results as JSON")]
     json: bool,
-    #[structopt(help = "Configuration profile to use", long, short, env = "SHPROFILE")]
+    #[structopt(
+        help = "Configuration profile to use",
+        long,
+        global = true,
+        env = "SHPROFILE"
+    )]
     profile: Option<String>,
     #[structopt(short, long, global = true)]
     verbose: bool,
@@ -113,7 +119,8 @@ enum Command {
             long,
             help = "Extra query parameters for create_state API call",
             parse(try_from_str = parse_params),
-            hidden = true
+            alias = "param",
+            hidden = true,
         )]
         params: Vec<(String, String)>,
     },
@@ -474,7 +481,7 @@ enum Command {
         #[structopt(help = "Namespace name")]
         namespace: String,
         #[structopt(help = "Cluster token")]
-        token: String,
+        cluster_token: String,
         #[structopt(help = "Kubeconfig context to use", long, short, visible_alias = "ctx")]
         context: Option<String>,
     },
@@ -859,9 +866,13 @@ impl Cli {
             }
             Command::SaveClusterToken {
                 namespace,
-                token,
+                cluster_token,
                 context,
-            } => statehub.save_cluster_token(namespace, token, context).await,
+            } => {
+                statehub
+                    .save_cluster_token(namespace, cluster_token, context)
+                    .await
+            }
             Command::SetupConfigmap {
                 cluster,
                 context,
